-- MySQL Workbench Synchronization
-- Generated: 2024-03-27 16:22:56
-- Model: nccs
-- Version: R08.08.01
-- Project: iDsteServers
-- Author:

SET @OLD_UNIQUE_CHECKS = @@UNIQUE_CHECKS, UNIQUE_CHECKS = 0;
SET @OLD_FOREIGN_KEY_CHECKS = @@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS = 0;
SET @OLD_SQL_MODE = @@SQL_MODE, SQL_MODE = 'TRADITIONAL,ALLOW_INVALID_DATES';

ALTER TABLE `nccs`.`Graphics`
    ADD COLUMN `Type` tinyint(4) UNSIGNED NOT NULL DEFAULT 0 COMMENT '图文素材类型，0 - 自定义素材(富文本)，1 - PDF文档，2 - PPT文档' AFTER `Name`,
    ADD COLUMN `FontParams` text CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NULL COMMENT '前端参数配置，json字符串' AFTER `Url`,
    ADD COLUMN `FileIDs` text CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NULL COMMENT '关联的文件ID，多个文件ID以逗号隔开' AFTER `FontParams`;


DROP TABLE IF EXISTS `nccs`.`ResourceFiles`;
CREATE TABLE `nccs`.`ResourceFiles`  (
    `id` int(11) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '文件ID',
    `type` tinyint(4) UNSIGNED NOT NULL DEFAULT 0 COMMENT '文件类型，0 图片，1 pdf，2 ppt',
    `origin_name` varchar(128) NOT NULL DEFAULT '' COMMENT '文件原始名称',
    `name` varchar(64) NOT NULL DEFAULT '' COMMENT '文件保存名称',
    `path` varchar(255) NOT NULL DEFAULT '' COMMENT '文件保存路径',
    `size` bigint(20) UNSIGNED NOT NULL DEFAULT 0 COMMENT '文件大小，单位：字节',
    `status` tinyint(4) UNSIGNED NOT NULL DEFAULT 1 COMMENT '文件状态，1 - 正常',
    `upload_by` int(11) UNSIGNED NULL DEFAULT NULL COMMENT '文件上传人ID',
    `modify_by` int(11) UNSIGNED NULL DEFAULT NULL COMMENT '修改人ID',
    `update_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    `create_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE INDEX `uidx_name`(`name`) USING BTREE COMMENT '保存名称索引',
    INDEX `idx_origin_name`(`origin_name`) USING BTREE COMMENT '原始名称索引'
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '资源文件表' ROW_FORMAT = DYNAMIC;

DROP TABLE IF EXISTS `nccs`.`NoticeAnnouncement`;
CREATE TABLE `nccs`.`NoticeAnnouncement` (
     `id` int NOT NULL AUTO_INCREMENT COMMENT '主键',
     `type` tinyint NOT NULL COMMENT '消息类型 0：默认消息，1：LC04消息',
     `title` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '标题',
     `content` varchar(8192) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '发布内容 富文本类型 ',
     `state` tinyint NOT NULL COMMENT '0:待审核、1：待发布、2：未通过：3已发布',
     `reason` varchar(255) COLLATE utf8mb4_general_ci NOT NULL DEFAULT '' COMMENT '驳回原因',
     `start_time` datetime DEFAULT NULL COMMENT '生效时间',
     `end_time` datetime DEFAULT NULL COMMENT '失效时间',
     `receiving_end_type` int NOT NULL DEFAULT '1' COMMENT '0: 设备 1：空间，2：分组',
     `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
     `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '修改时间',
     `create_user_id` int NOT NULL DEFAULT '0' COMMENT '创建用户ID',
     PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci ROW_FORMAT=DYNAMIC;


DROP TABLE IF EXISTS `nccs`.`NoticeAnnouncementPartitionNode`;
CREATE TABLE  `nccs`.`NoticeAnnouncementPartitionNode` (
   `id` int NOT NULL AUTO_INCREMENT,
   `notice_announcement_id` int NOT NULL,
   `partition_id` int NOT NULL,
   PRIMARY KEY (`id`) USING BTREE,
   UNIQUE KEY `session_id` (`notice_announcement_id`,`partition_id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb3 ROW_FORMAT=DYNAMIC COMMENT='设备消息通知空间表';

-- 考勤流水表基础表
CREATE TABLE IF NOT EXISTS `AttendanceFlow`  (
  `Id` int(11) NOT NULL AUTO_INCREMENT,
  `TermName` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '学年-学期。如：2023-2024-1',
  `Date` varchar(20) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '上课日期',
  `Week` int(11) NOT NULL DEFAULT 0 COMMENT '上课周次',
  `WeekDay` tinyint(4) NOT NULL DEFAULT 0 COMMENT '上课星期',
  `StartSection` int(11) NOT NULL DEFAULT 0 COMMENT '开始节次',
  `Start` varchar(10) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '开始时间',
  `EndSection` int(11) NOT NULL DEFAULT 0 COMMENT '结束节次',
  `End` varchar(10) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '结束时间',
  `SpaceID` int(11) NOT NULL DEFAULT 0 COMMENT '空间ID',
  `SpaceName` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '空间名称',
  `UserID` int(11) NOT NULL DEFAULT 0,
  `UserSn` varchar(50) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '学生学工号',
  `UserName` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '用户姓名',
  `TeacherInfo` varchar(1024) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '上课老师信息，json',
  `Major` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '专业',
  `Class` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '班级',
  `CourseName` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '课程名称',
  `SignInType` tinyint(4) UNSIGNED NOT NULL DEFAULT 0 COMMENT '1:ic卡 2:指纹 3:用户ID 4:二维码 5:人脸',
  `SignedTime` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '签到时间',
  PRIMARY KEY (`Id`) USING BTREE,
  UNIQUE INDEX `only`(`Date`, `StartSection`, `EndSection`, `SpaceID`, `UserSn`) USING BTREE,
  INDEX `userIdKey_idx`(`UserSn`) USING BTREE,
  INDEX `deviceId_idx`(`SpaceID`) USING BTREE,
  INDEX `date_idx`(`Date`) USING BTREE,
  INDEX `signTime_idx`(`SignedTime`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '考勤流水表' ROW_FORMAT = DYNAMIC;

-- 课表相关更改
ALTER TABLE `nccs`.`Timetable` ADD COLUMN `RId` varchar(32) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '教务课表id' AFTER `Id`;
ALTER TABLE `nccs`.`Timetable` ADD COLUMN `Date` varchar(20) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '上课日期' AFTER `TermName`;
ALTER TABLE `nccs`.`Timetable` ADD COLUMN `Signed` smallint(1) NOT NULL DEFAULT 0 COMMENT '老师是否已经签到' AFTER `UserId`;
ALTER TABLE `nccs`.`Timetable` ADD COLUMN `SignInType` tinyint NOT NULL DEFAULT 0 COMMENT '1:ic卡 2:指纹 3:用户ID 4:二维码 5:人脸' AFTER `Signed`;
ALTER TABLE `nccs`.`Timetable` ADD COLUMN `Student` longtext CHARACTER SET utf8mb4 COLLATE utf8mb4_bin COMMENT '上课学生信息，json' AFTER `Major`;
ALTER TABLE `nccs`.`Timetable` ADD COLUMN `SignedStudentInfo` longtext CHARACTER SET utf8mb4 COLLATE utf8mb4_bin COMMENT '已签到学生信息(签到人数，未签到人数，未签到学生信息，已签到学生信息)，json' AFTER `Student`;

ALTER TABLE `nccs`.`Users` ADD COLUMN `UseStartTime` time DEFAULT NULL COMMENT '使用权限生效开始时间' AFTER `NotPopUp`;
ALTER TABLE `nccs`.`Users` ADD COLUMN `UseEndTime` time DEFAULT NULL COMMENT '使用权限生效结束时间' AFTER `UseStartTime`;



-- ----------------------------
-- Table structure for UserPhoto
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`UserPhoto`;
CREATE TABLE `nccs`.`UserPhoto`  (
    `id` int(11) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '自增主键',
    `user_id` int(11) UNSIGNED NULL DEFAULT NULL COMMENT '关联的用户ID',
    `origin_name` varchar(64) NOT NULL DEFAULT '' COMMENT '照片原始名称(上传名称)',
    `name` varchar(32) NOT NULL DEFAULT '' COMMENT '照片名称(存盘名称)',
    `size` bigint(20) UNSIGNED NOT NULL DEFAULT 0 COMMENT '照片大小，单位：字节',
    `width` int(11) UNSIGNED NOT NULL DEFAULT 0 COMMENT '照片宽度',
    `height` int(11) UNSIGNED NOT NULL DEFAULT 0 COMMENT '照片高度',
    `md5` varchar(32) NOT NULL DEFAULT '' COMMENT '照片MD5',
    `status` tinyint(1) UNSIGNED NOT NULL DEFAULT 1 COMMENT '照片状态：1 - 已上传，但未进行特征码解析；2 - 正常状态，已解析生成人脸特征码',
    `source` tinyint(2) UNSIGNED NOT NULL DEFAULT 1 COMMENT '照片来源，1 - 本地上传',
    `face_code` varchar(2048) NULL DEFAULT '' COMMENT '人脸特征码',
    `fc_hash` varchar(64) NULL DEFAULT NULL COMMENT '人脸特征码SHA-256哈希值',
    `fc_sdk` tinyint(2) UNSIGNED NOT NULL DEFAULT 0 COMMENT '生成人脸特征码的sdk，1-百度，2-瑞芯微',
    `upload_by` int(11) NULL DEFAULT NULL COMMENT '照片上传人ID',
    `update_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    `create_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE INDEX `uidx_name`(`name`) USING BTREE COMMENT '保存名称索引',
    UNIQUE INDEX `uidx_fc_hash`(`fc_hash`) USING BTREE COMMENT '特征码哈希索引',
    INDEX `idx_origin_name`(`origin_name`) USING BTREE COMMENT '原始名称索引',
    INDEX `idx_md5`(`md5`) USING BTREE COMMENT 'md5索引'
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '用户照片表' ROW_FORMAT = DYNAMIC;


ALTER TABLE `nccs`.`DeviceList` ADD COLUMN `ReceivingEndType` tinyint(2) UNSIGNED NOT NULL DEFAULT 1 COMMENT '接收节点类型，0: 设备 1：空间，2：分组' AFTER `ProtocolDevName`;


-- ----------------------------
-- Table structure for DevPartitionNode
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`DevPartitionNode`;
CREATE TABLE `nccs`.`DevPartitionNode`  (
    `dev_id` varchar(50) NOT NULL COMMENT '设备ID',
    `partition_id` int(11) UNSIGNED NOT NULL COMMENT '分区节点ID',
    `create_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`dev_id`) USING BTREE,
    UNIQUE INDEX `uidx_devid_nodeid`(`dev_id`, `partition_id`) USING BTREE COMMENT '设备ID和分区节点ID索引'
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '设备分区节点绑定表' ROW_FORMAT = DYNAMIC;



-- ----------------------------
-- Table structure for TermHistoryConfig
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`TermHistoryConfig`;
CREATE TABLE `nccs`.`TermHistoryConfig`  (
    `id` int(11) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键ID',
    `code` varchar(64) NOT NULL COMMENT '学年编号',
    `open` date NOT NULL COMMENT '开学日期',
    `end` date NOT NULL COMMENT '结束日期',
    `modify_by` int(11) NULL DEFAULT NULL COMMENT '修改人',
    `update_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    `create_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE INDEX `uidx_code`(`code`) USING BTREE COMMENT '学年编号索引'
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '学期历史配置表' ROW_FORMAT = DYNAMIC;


SET SQL_MODE = @OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS = @OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS = @OLD_UNIQUE_CHECKS;
