-- MySQL Workbench Synchronization
-- Generated: 2023-09-11 10:41:16
-- Model: nccs
-- Version: D08.05.01
-- Project: iDsteServers
-- Author:

SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

-- D08.05.01
CREATE TABLE IF NOT EXISTS `nccs`.`Asset`  (
    `id` int(11) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '资产编号，从1开始自增',
    `space_id` int(11) UNSIGNED NULL DEFAULT NULL COMMENT '资产归属空间',
    `sn` varchar(64) NOT NULL DEFAULT '' COMMENT '资产序列号，idste资产为设备ID',
    `introduction_time` varchar(32) NOT NULL DEFAULT '' COMMENT '资产启用时间，YYYY-MM-DD格式',
    `status` smallint(6) UNSIGNED NOT NULL DEFAULT 1 COMMENT '资产状态,1-在用，2-报废',
    `vendor` varchar(255) NOT NULL DEFAULT '' COMMENT '资产厂商',
    `asset_class` varchar(64) NOT NULL DEFAULT '' COMMENT '资产分类',
    `asset_type` varchar(64) NOT NULL DEFAULT '' COMMENT '资产具体型号',
    `num_prefix` varchar(64) NOT NULL DEFAULT '' COMMENT '资产编号前缀',
    `rated_life` smallint(6) UNSIGNED NOT NULL DEFAULT 0 COMMENT '资产额定寿命，单位：月',
    `supplier` varchar(255) NOT NULL DEFAULT '' COMMENT '供货商',
    `purchase_time` varchar(32) NOT NULL DEFAULT '' COMMENT '采购时间，YYYY-MM-DD格式',
    `purchase_amount` int(11) UNSIGNED NOT NULL DEFAULT 0 COMMENT '采购数量',
    `warranty_expire_time` varchar(32) NOT NULL DEFAULT '' COMMENT '资产质保过期时间，YYYY-MM-DD格式',
    `update_user` int(11) UNSIGNED NULL DEFAULT NULL COMMENT '记录更新用户ID',
    `is_deleted` tinyint(1) UNSIGNED NOT NULL DEFAULT 0 COMMENT '是否删除，0-未删除，1-已删除',
    `remark` varchar(1024) NOT NULL DEFAULT '' COMMENT '备注',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '记录更新时间',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '记录创建时间',
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE INDEX `sn_index`(`sn`) USING BTREE COMMENT 'sn索引'
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '资产信息表' ROW_FORMAT = DYNAMIC;


CREATE TABLE IF NOT EXISTS `nccs`.`AssetBatch`  (
    `id` int(11) UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '主键，批次ID',
    `vendor` varchar(255) NOT NULL DEFAULT '' COMMENT '资产厂商',
    `asset_class` varchar(64) NOT NULL DEFAULT '' COMMENT '资产分类',
    `asset_type` varchar(64) NOT NULL DEFAULT '' COMMENT '资产具体型号',
    `num_prefix` varchar(64) NOT NULL DEFAULT '' COMMENT '资产编号前缀',
    `rated_life` smallint(6) UNSIGNED NOT NULL DEFAULT 0 COMMENT '资产额定寿命，单位：月',
    `supplier` varchar(255) NOT NULL DEFAULT '' COMMENT '供货商',
    `purchase_time` varchar(32) NOT NULL DEFAULT '' COMMENT '采购时间，YYYY-MM-DD格式',
    `purchase_amount` int(11) UNSIGNED NOT NULL DEFAULT 0 COMMENT '采购数量',
    `warranty_expire_time` varchar(32) NOT NULL DEFAULT '' COMMENT '资产质保过期时间，YYYY-MM-DD格式',
    `update_user` int(11) UNSIGNED NULL DEFAULT NULL COMMENT '记录更新用户ID',
    `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '资产批次录入表' ROW_FORMAT = DYNAMIC;



-- D08.05.03
-- -----------------------------------------------------
-- Table structure for ICarePCBaseInfo
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`ICarePCBaseInfo`  (
                                                         `id` int NOT NULL AUTO_INCREMENT,
                                                         `uuid` varchar(255)  NOT NULL DEFAULT '' COMMENT 'pc设备uuid',
                                                         `name` varchar(255)  NOT NULL DEFAULT '' COMMENT 'idstecare名称',
                                                         `version` varchar(255)  NOT NULL DEFAULT '' COMMENT 'pc安装的icare的版本',
                                                         `host_name` varchar(255)  NOT NULL DEFAULT '' COMMENT 'pc主机名称',
                                                         `os` varchar(255)  NOT NULL DEFAULT '' COMMENT '操作系统版本',
                                                         `hardware` varchar(2048)  NOT NULL DEFAULT '' COMMENT '硬件信息',
                                                         `network_card` varchar(4096)  NOT NULL DEFAULT '' COMMENT '网卡信息列表。json格式',
                                                         `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                                                         PRIMARY KEY (`id`) USING BTREE,
                                                         UNIQUE INDEX `uuid_index`(`uuid` ASC) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin ROW_FORMAT = Dynamic;

-- -----------------------------------------------------
-- Table structure for ICarePCConfig
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`ICarePCConfig`  (
                                                       `id` int NOT NULL AUTO_INCREMENT,
                                                       `uuid` varchar(255)  NOT NULL COMMENT 'pc uuid',
                                                       `name` varchar(255)  NOT NULL COMMENT 'idstecare名称',
                                                       `device_id` varchar(10)  NOT NULL COMMENT '绑定设备id',
                                                       `device_ip` varchar(15)  NOT NULL COMMENT '绑定设备ip',
                                                       `broker_ip` varchar(15)  NOT NULL COMMENT '服务器ip',
                                                       `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                                                       PRIMARY KEY (`id`) USING BTREE,
                                                       UNIQUE INDEX `uuid_index`(`uuid` ASC) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin ROW_FORMAT = Dynamic;

ALTER TABLE `nccs`.`Timetable` DROP INDEX `only`;
ALTER TABLE `nccs`.`Timetable` ADD COLUMN `Week` int(3) NOT NULL DEFAULT 0 COMMENT '上课周次' AFTER `TermName`;
ALTER TABLE `nccs`.`Timetable` ADD UNIQUE INDEX `only`(`TermName` ASC, `Week` ASC, `WeekDay` ASC, `Start` ASC, `End` ASC, `SpaceID` ASC, `UserId` ASC) USING BTREE;

ALTER TABLE `nccs`.`SystemLog` MODIFY COLUMN `detail` varchar(2048) CHARACTER SET utf8 COLLATE utf8_general_ci NULL DEFAULT NULL AFTER `action`;

ALTER TABLE `nccs`.`RfConfig` MODIFY COLUMN `PwrID` int(11) NOT NULL FIRST;

ALTER TABLE `nccs`.`RfConfig` ADD COLUMN `VendorID` int(11) NOT NULL DEFAULT 0 COMMENT '厂家ID' AFTER `DevID`;

ALTER TABLE `nccs`.`RfConfig` ADD COLUMN `ProductID` int(11) NOT NULL DEFAULT 0 COMMENT '产品类型ID' AFTER `VendorID`;

ALTER TABLE `nccs`.`RfConfig` ADD COLUMN `URI` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' AFTER `ProductID`;


UPDATE RfConfig r INNER JOIN RfChildType child on child.ID=r.ChildType  SET r.VendorID=1,r.ProductID=2 WHERE child.RfType=0;
UPDATE RfConfig r INNER JOIN RfChildType child on child.ID=r.ChildType  SET r.VendorID=1,r.ProductID=3 WHERE child.RfType=1;
UPDATE RfConfig r INNER JOIN RfChildType child on child.ID=r.ChildType  SET r.VendorID=1,r.ProductID=4 WHERE child.RfType=2;


-- D08.05.05
-- 调整状态字段类型
ALTER TABLE `nccs`.`DevUsedStatusV2` MODIFY COLUMN `Status` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'offline:离线 online:在线 pwrOn:开机 pwrOff:关机 using:使用中 isPushing:推流中 takeout:取离';

-- 课表字段调整
ALTER TABLE `nccs`.`Timetable` DROP INDEX `only`;
ALTER TABLE `nccs`.`Timetable` DROP COLUMN `Start`;
ALTER TABLE `nccs`.`Timetable` DROP COLUMN `End`;
ALTER TABLE `nccs`.`Timetable` DROP COLUMN `ClassName`;
ALTER TABLE `nccs`.`Timetable` DROP COLUMN `UserSn`;
ALTER TABLE `nccs`.`Timetable` DROP COLUMN `UserName`;
ALTER TABLE `nccs`.`Timetable` ADD COLUMN `Zone` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '校区' AFTER `EndSection`;
ALTER TABLE `nccs`.`Timetable` CHARACTER SET = utf8mb4, COLLATE = utf8mb4_bin;
ALTER TABLE `nccs`.`Timetable` MODIFY COLUMN `TermName` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '学年-学期。如：2023-2024-1' AFTER `Id`;
ALTER TABLE `nccs`.`Timetable` MODIFY COLUMN `CourseName` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT '' COMMENT '课程名称' AFTER `UserId`;
ALTER TABLE `nccs`.`Timetable` MODIFY COLUMN `Type` enum('normal','temporary') CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL DEFAULT 'normal' COMMENT 'normal:正课\ntemporary:临课' AFTER `CourseName`;
ALTER TABLE `nccs`.`Timetable` MODIFY COLUMN `SpaceID` int(11) NOT NULL DEFAULT 0 COMMENT '空间ID' AFTER `Zone`;
ALTER TABLE `nccs`.`Timetable` ADD UNIQUE INDEX `only`(`TermName` ASC, `Week` ASC, `WeekDay` ASC, `StartSection` ASC, `EndSection` ASC, `SpaceID` ASC, `UserId` ASC) USING BTREE;




-- D08.05.06
ALTER TABLE `nccs`.`DeviceUsedTime` ADD INDEX `index`(`StatisticDay`, `DeviceID`, `SubID`) USING BTREE;


-- D08.05.10
ALTER TABLE `nccs`.`Asset`
    ADD INDEX `class_idx`(`asset_class`) USING BTREE COMMENT '分类索引',
    ADD INDEX `type_idx`(`asset_type`) USING BTREE COMMENT '型号索引';



-- D08.05.11
ALTER TABLE `nccs`.`Firmware`
    ADD COLUMN `os_version` varchar(32) NOT NULL DEFAULT '' COMMENT '固件os版本' AFTER `version`,
    ADD COLUMN `app_name` varchar(255) NOT NULL DEFAULT '' COMMENT 'app名称' AFTER `os_version`,
    ADD COLUMN `pkg_name` varchar(255) NOT NULL DEFAULT '' COMMENT 'app包名' AFTER `app_name`;

UPDATE `nccs`.`Firmware` SET `os_version` = `notes` WHERE `chip` <> 'app' AND `notes` <> '' AND CHAR_LENGTH(`notes`) < 33;
UPDATE `nccs`.`Firmware` SET `app_name` = `notes` WHERE `chip` = 'app' AND `notes` <> '';



-- D08.05.12
CREATE TABLE IF NOT EXISTS `nccs`.`AuxDevices`  (
        `dev_id` varchar(55) NOT NULL DEFAULT '' COMMENT '附属设备ID',
        `proto_dev_name` varchar(16) NOT NULL DEFAULT '' COMMENT '附属设备协议设备类型',
        `last_bind_dev_id` varchar(55) NOT NULL DEFAULT '' COMMENT '附属设备最后绑定的中控id',
        `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
        `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
        PRIMARY KEY (`dev_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8mb4 COLLATE = utf8mb4_bin COMMENT = '中控附属面板设备表' ROW_FORMAT = Dynamic;


-- D08.05.14
ALTER TABLE `nccs`.`Firmware` ADD COLUMN `forPlat` tinyint(1) NOT NULL DEFAULT 0 COMMENT '表示应用到哪个平台。0：嵌入式设备 1：电脑助手iDsteCare' AFTER `file_path`;

ALTER TABLE `nccs`.`Firmware` ADD COLUMN `arch` varchar(255) NOT NULL DEFAULT '' COMMENT '指令集架构' AFTER `chip`;

ALTER TABLE `nccs`.`Firmware` ADD COLUMN `hash` varchar(255) NOT NULL DEFAULT '' COMMENT '文件hash值' AFTER `md5`;

ALTER TABLE `nccs`.`Firmware` ADD COLUMN `version_v2` varchar(255) NOT NULL DEFAULT '' AFTER `version`;

ALTER TABLE `nccs`.`Firmware` ADD COLUMN `os` varchar(32) NOT NULL DEFAULT '' COMMENT '安装包/升级包支持的系统的名称' AFTER `version_v2`;





SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;